`xotl.tools.validators.identifiers`:mod: -- Simple identifiers validators
=========================================================================

.. automodule:: xotl.tools.validators.identifiers
   :members:
